==> tinybig-0.1.0.post5.tar.gz: tinybig-0.1.0.post5/docs/documentations/expansion/index.md <==
# tinybig.expansion

::: tinybig.expansion

---------------------------------------
## Data Expansion/Transformation
* [transformation](../module/transformation.md) (defined in the tinybig.module directory)

## Basic Expansions
* [identity_expansion](identity_expansion.md)
* [reciprocal_expansion](reciprocal_expansion.md)
* [linear_expansion](linear_expansion.md)

## Polynomial Expansions
* [taylor_expansion](taylor_expansion.md)
* [fourier_expansion](fourier_expansion.md)
* [bspline_expansion](bspline_expansion.md)
* [chebyshev_expansion](chebyshev_expansion.md)
* [jacobi_expansion](jacobi_expansion.md)

## Trigonometric Expansions
* [hyperbolic_expansion](hyperbolic_expansion.md)
* [arc_hyperbolic_expansion](arc_hyperbolic_expansion.md)
* [trigonometric_expansion](trigonometric_expansion.md)
* [arc_trigonometric_expansion](arc_trigonometric_expansion.md)

## RBF Expansions
* [gaussian_rbf_expansion](gaussian_rbf_expansion.md)
* [inverse_quadratic_rbf_expansion](inverse_quadratic_rbf_expansion.md)

## Naive Probabilistic Expansions
* [naive_normal_expansion](naive_normal_expansion.md)
* [naive_cauchy_expansion](naive_cauchy_expansion.md)
* [naive_chi2_expansion](naive_chi2_expansion.md)
* [naive_gamma_expansion](naive_gamma_expansion.md)
* [naive_exponential_expansion](naive_exponential_expansion.md)
* [naive_laplace_expansion](naive_laplace_expansion.md)

## Combinatorial Probabilistic Expansions
* [combinatorial_expansion](combinatorial_expansion.md)
* [combinatorial_normal_expansion](combinatorial_normal_expansion.md)

## Nested and Extended expansions
* [nested_expansion](nested_expansion.md)
* [extended_expansion](extended_expansion.md)

==> tinybig-0.1.1.tar.gz: tinybig-0.1.1/docs/documentations/expansion/index.md <==
# tinybig.expansion

::: tinybig.expansion

---------------------------------------
## Organization of this Module

### Data Expansion/Transformation
* [transformation](../module/transformation.md) (defined in the tinybig.module directory)

### Basic Expansions
* [identity_expansion](identity_expansion.md)
* [reciprocal_expansion](reciprocal_expansion.md)
* [linear_expansion](linear_expansion.md)

### Polynomial Expansions
* [taylor_expansion](taylor_expansion.md)
* [fourier_expansion](fourier_expansion.md)
* [bspline_expansion](bspline_expansion.md)
* [chebyshev_expansion](chebyshev_expansion.md)
* [jacobi_expansion](jacobi_expansion.md)

### Trigonometric Expansions
* [hyperbolic_expansion](hyperbolic_expansion.md)
* [arc_hyperbolic_expansion](arc_hyperbolic_expansion.md)
* [trigonometric_expansion](trigonometric_expansion.md)
* [arc_trigonometric_expansion](arc_trigonometric_expansion.md)

### RBF Expansions
* [gaussian_rbf_expansion](gaussian_rbf_expansion.md)
* [inverse_quadratic_rbf_expansion](inverse_quadratic_rbf_expansion.md)

### Naive Probabilistic Expansions
* [naive_normal_expansion](naive_normal_expansion.md)
* [naive_cauchy_expansion](naive_cauchy_expansion.md)
* [naive_chi2_expansion](naive_chi2_expansion.md)
* [naive_gamma_expansion](naive_gamma_expansion.md)
* [naive_exponential_expansion](naive_exponential_expansion.md)
* [naive_laplace_expansion](naive_laplace_expansion.md)

### Combinatorial Probabilistic Expansions
* [combinatorial_expansion](combinatorial_expansion.md)
* [combinatorial_normal_expansion](combinatorial_normal_expansion.md)

### Nested and Extended expansions
* [nested_expansion](nested_expansion.md)
* [extended_expansion](extended_expansion.md)
